#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['pokemon_yeet']

package_data = \
{'': ['*']}

install_requires = \
['requests >= 2.25.1']

entry_points = \
{'console_scripts': ['pokemon-yeet = pokemon_yeet.pokemon:main']}

setup(name='pokemon-yeet-2ndbillingcycle',
      version='0.0.4',
      description='This is an auto battling pokemon cli game',
      author='2ndBillingCycle',
      author_email='2nd+github@2ndbillingcycle.stream',
      url='https://github.com/2ndbillingcycle/pokemon_yeet',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      entry_points=entry_points,
      python_requires='>=3.7,<4',
     )
